# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import cloud_service_type_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2


class CloudServiceTypeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CreateCloudServiceTypeRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.UpdateCloudServiceTypeRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.GetCloudServiceTypeRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.allow_delete_stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudServiceType/allow_delete_stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class CloudServiceTypeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new CloudServiceType. You must specify the `name`, `provider`, and `group` parameters to create a CloudServiceType. One or several CloudServiceTypes exist in a specific `group`, and each CloudServiceType is identified by the `name` parameter.
        request_example: >-
        {
        "name": "API-TEST",
        "provider": "aws",
        "group": "APIGateway",
        "service_code": "AmazonApiGateway",
        "is_primary": true,
        "is_major": true,
        "resource_type": "inventory.CloudService",
        "metadata": {},
        "labels": [
        "Networking"
        ],
        "tags": {
        "a": "b"
        }
        }
        response_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8",
        "name": "API-TEST",
        "provider": "aws",
        "group": "APIGateway",
        "cloud_service_type_key": "aws.APIGateway.API-TEST",
        "service_code": "AmazonApiGateway",
        "is_primary": true,
        "is_major": true,
        "resource_type": "inventory.CloudService",
        "metadata": {},
        "tags": {
        "a": "b"
        },
        "labels": [
        "Networking"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T01:38:16.301Z",
        "updated_at": "2022-06-22T01:38:16.301Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific CloudServiceType. You can make changes in CloudServiceType settings, except for `name`, `provider` and `group`. In particular, you can set the CloudServiceType's priority in a `group`.
        request_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8",
        "service_code": "AmazonApi",
        "metadata": {},
        "labels": [
        "Networking2"
        ],
        "tags": {
        "b": "c"
        }
        }
        response_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8",
        "name": "API-TEST",
        "provider": "aws",
        "group": "APIGateway",
        "cloud_service_type_key": "aws.APIGateway.API-TEST",
        "service_code": "AmazonApi",
        "is_primary": true,
        "is_major": true,
        "resource_type": "inventory.CloudService",
        "metadata": {},
        "tags": {
        "b": "c"
        },
        "labels": [
        "Networking2"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T01:38:16.301Z",
        "updated_at": "2022-06-22T02:12:11.184Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific CloudServiceType. You must specify the `cloud_service_type_id` of the CloudServiceType to delete.
        request_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific CloudServiceType. Prints detailed information about the CloudServiceType.
        request_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8"
        }
        response_example: >-
        {
        "cloud_service_type_id": "cloud-svc-type-27dd73ac89f8",
        "name": "API-TEST",
        "provider": "aws",
        "group": "APIGateway",
        "cloud_service_type_key": "aws.APIGateway.API-TEST",
        "service_code": "AmazonApi",
        "is_primary": true,
        "is_major": true,
        "resource_type": "inventory.CloudService",
        "metadata": {},
        "tags": {
        "b": "c"
        },
        "labels": [
        "Networking2"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T01:38:16.301Z",
        "updated_at": "2022-06-22T02:12:11.184Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all CloudServiceTypes. You can use a query to get a filtered list of CloudServiceTypes.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "provider",
        "value": "aws",
        "operator": "eq"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [
        {
        "cloud_service_type_id": "cloud-svc-type-7e1c113b39ff",
        "name": "API",
        "provider": "aws",
        "group": "APIGateway",
        "cloud_service_type_key": "aws.APIGateway.API",
        "service_code": "AmazonApiGateway",
        "is_primary": true,
        "is_major": true,
        "resource_type": "inventory.CloudService",
        "metadata": {
        },
        "tags": {
        "spaceone:icon": "https://spaceone.s3.ap-northeast-2.amazonaws.com/console-assets/icons/cloud-services/aws/Amazon-API-Gateway.svg"
        },
        "labels": [
        "Networking"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-03T02:29:32.690Z",
        "updated_at": "2022-06-22T00:04:45.477Z"
        },
        {
        "cloud_service_type_id": "cloud-svc-type-64a0de601371",
        "name": "Certificate",
        "provider": "aws",
        "group": "CertificateManager",
        "cloud_service_type_key": "aws.CertificateManager.Certificate",
        "service_code": "AWSCertificateManager",
        "is_primary": true,
        "resource_type": "inventory.CloudService",
        "metadata": {
        },
        "tags": {
        "spaceone:icon": "https://spaceone.s3.ap-northeast-2.amazonaws.com/console-assets/icons/cloud-services/aws/AWS-Certificate-Manager.svg"
        },
        "labels": [
        "Security"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-03T02:29:53.052Z",
        "updated_at": "2022-06-22T00:05:41.252Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def allow_delete_stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceTypeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CreateCloudServiceTypeRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.UpdateCloudServiceTypeRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.GetCloudServiceTypeRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'allow_delete_stat': grpc.unary_unary_rpc_method_handler(
                    servicer.allow_delete_stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.CloudServiceType', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CloudServiceType(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CreateCloudServiceTypeRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.UpdateCloudServiceTypeRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.GetCloudServiceTypeRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def allow_delete_stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudServiceType/allow_delete_stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__type__pb2.CloudServiceTypeStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/provisioning/v1/resource_group.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x8b\x01\n\x12ResourceGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"M\n\x1a\x43reateResourceGroupRequest\x12\x1b\n\x13resource_group_name\x18\x01 \x01(\t\x12\x12\n\nsort_order\x18\x02 \x01(\t\"h\n\x1aUpdateResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x02 \x01(\t\x12\x12\n\nsort_order\x18\x03 \x01(\x05\"D\n\x14ResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"a\n\x16ResourceGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x9a\x01\n\x11ResourceGroupInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x12\n\nsort_order\x18\x04 \x01(\x05\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"k\n\x12ResourceGroupsInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.provisioning.v1.ResourceGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x9e\x08\n\rResourceGroup\x12\xab\x01\n\x15\x63reate_resource_group\x12\x38.spaceone.api.provisioning.v1.CreateResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/provisioning/v1/resource-group\x12\xce\x01\n\x13get_resource_groups\x12\x30.spaceone.api.provisioning.v1.ResourceGroupQuery\x1a\x30.spaceone.api.provisioning.v1.ResourceGroupsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /provisioning/v1/resource-groupsZ)\"\'/provisioning/v1/resource-groups/search\x12\xb6\x01\n\x12get_resource_group\x12\x32.spaceone.api.provisioning.v1.ResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/provisioning/v1/resource-group/{resource_group_id}\x12\xab\x01\n\x15update_resource_group\x12\x38.spaceone.api.provisioning.v1.UpdateResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/provisioning/v1/resource-group\x12\xa0\x01\n\x15\x64\x65lete_resource_group\x12\x32.spaceone.api.provisioning.v1.ResourceGroupRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35*3/provisioning/v1/resource-group/{resource_group_id}\x12\x83\x01\n\x04stat\x12\x34.spaceone.api.provisioning.v1.ResourceGroupStatQuery\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/provisioning/v1/resource-group/statb\x06proto3')



_RESOURCEGROUPQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupQuery']
_CREATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceGroupRequest']
_UPDATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceGroupRequest']
_RESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResourceGroupRequest']
_RESOURCEGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupStatQuery']
_RESOURCEGROUPINFO = DESCRIPTOR.message_types_by_name['ResourceGroupInfo']
_RESOURCEGROUPSINFO = DESCRIPTOR.message_types_by_name['ResourceGroupsInfo']
ResourceGroupQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupQuery)
  })
_sym_db.RegisterMessage(ResourceGroupQuery)

CreateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('CreateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceGroupRequest)
  })
_sym_db.RegisterMessage(CreateResourceGroupRequest)

UpdateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceGroupRequest)
  })
_sym_db.RegisterMessage(UpdateResourceGroupRequest)

ResourceGroupRequest = _reflection.GeneratedProtocolMessageType('ResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupRequest)
  })
_sym_db.RegisterMessage(ResourceGroupRequest)

ResourceGroupStatQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupStatQuery)
  })
_sym_db.RegisterMessage(ResourceGroupStatQuery)

ResourceGroupInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupInfo)
  })
_sym_db.RegisterMessage(ResourceGroupInfo)

ResourceGroupsInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupsInfo)
  })
_sym_db.RegisterMessage(ResourceGroupsInfo)

_RESOURCEGROUP = DESCRIPTOR.services_by_name['ResourceGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEGROUP.methods_by_name['create_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['create_resource_group']._serialized_options = b'\202\323\344\223\002!\"\037/provisioning/v1/resource-group'
  _RESOURCEGROUP.methods_by_name['get_resource_groups']._options = None
  _RESOURCEGROUP.methods_by_name['get_resource_groups']._serialized_options = b'\202\323\344\223\002M\022 /provisioning/v1/resource-groupsZ)\"\'/provisioning/v1/resource-groups/search'
  _RESOURCEGROUP.methods_by_name['get_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['get_resource_group']._serialized_options = b'\202\323\344\223\0025\0223/provisioning/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['update_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['update_resource_group']._serialized_options = b'\202\323\344\223\002!\032\037/provisioning/v1/resource-group'
  _RESOURCEGROUP.methods_by_name['delete_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['delete_resource_group']._serialized_options = b'\202\323\344\223\0025*3/provisioning/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['stat']._options = None
  _RESOURCEGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002&\"$/provisioning/v1/resource-group/stat'
  _RESOURCEGROUPQUERY._serialized_start=207
  _RESOURCEGROUPQUERY._serialized_end=346
  _CREATERESOURCEGROUPREQUEST._serialized_start=348
  _CREATERESOURCEGROUPREQUEST._serialized_end=425
  _UPDATERESOURCEGROUPREQUEST._serialized_start=427
  _UPDATERESOURCEGROUPREQUEST._serialized_end=531
  _RESOURCEGROUPREQUEST._serialized_start=533
  _RESOURCEGROUPREQUEST._serialized_end=601
  _RESOURCEGROUPSTATQUERY._serialized_start=603
  _RESOURCEGROUPSTATQUERY._serialized_end=700
  _RESOURCEGROUPINFO._serialized_start=703
  _RESOURCEGROUPINFO._serialized_end=857
  _RESOURCEGROUPSINFO._serialized_start=859
  _RESOURCEGROUPSINFO._serialized_end=966
  _RESOURCEGROUP._serialized_start=969
  _RESOURCEGROUP._serialized_end=2023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/project_channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/notification/v1/project_channel.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xe9\x01\n\x16ProjectChannelSchedule\x12S\n\x0b\x64\x61y_of_week\x18\x01 \x03(\x0e\x32>.spaceone.api.notification.v1.ProjectChannelSchedule.DayOfWeek\x12\x12\n\nstart_hour\x18\x02 \x01(\x05\x12\x10\n\x08\x65nd_hour\x18\x03 \x01(\x05\"T\n\tDayOfWeek\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03MON\x10\x01\x12\x07\n\x03TUE\x10\x02\x12\x07\n\x03WED\x10\x03\x12\x07\n\x03THU\x10\x04\x12\x07\n\x03\x46RI\x10\x05\x12\x07\n\x03SAT\x10\x06\x12\x07\n\x03SUN\x10\x07\"\x8d\x03\n\x1b\x43reateProjectChannelRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cis_subscribe\x18\x04 \x01(\x08\x12\x15\n\rsubscriptions\x18\x05 \x03(\t\x12K\n\x12notification_level\x18\x06 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x14\n\x0cis_scheduled\x18\x07 \x01(\x08\x12\x46\n\x08schedule\x18\x08 \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xf5\x01\n\x1bUpdateProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x12notification_level\x18\x05 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xb2\x01\n#UpdateProjectChannelScheduleRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_scheduled\x18\x02 \x01(\x08\x12\x46\n\x08schedule\x18\x03 \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\x85\x01\n\'UpdateProjectChannelSubscriptionRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x02 \x01(\x08\x12\x15\n\rsubscriptions\x18\x03 \x03(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"F\n\x15ProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"W\n\x18GetProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x99\x03\n\x13ProjectChannelQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1a\n\x12project_channel_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12T\n\x05state\x18\x04 \x01(\x0e\x32\x45.spaceone.api.notification.v1.ProjectChannelQuery.ProjectChannelState\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12K\n\x12notification_level\x18\x06 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x13\n\x0bprotocol_id\x18\x0b \x01(\t\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\":\n\x13ProjectChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xd8\x04\n\x12ProjectChannelInfo\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12S\n\x05state\x18\x03 \x01(\x0e\x32\x44.spaceone.api.notification.v1.ProjectChannelInfo.ProjectChannelState\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x06 \x01(\x08\x12\x15\n\rsubscriptions\x18\x07 \x03(\t\x12K\n\x12notification_level\x18\x08 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x14\n\x0cis_scheduled\x18\t \x01(\x08\x12\x46\n\x08schedule\x18\n \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bprotocol_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\":\n\x13ProjectChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"m\n\x13ProjectChannelsInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.notification.v1.ProjectChannelInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17ProjectChannelStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*J\n\x11NotificationLevel\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03LV1\x10\x01\x12\x07\n\x03LV2\x10\x02\x12\x07\n\x03LV3\x10\x03\x12\x07\n\x03LV4\x10\x04\x12\x07\n\x03LV5\x10\x05\x32\x9b\x0e\n\x0eProjectChannel\x12\xa0\x01\n\x06\x63reate\x12\x39.spaceone.api.notification.v1.CreateProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\")\x82\xd3\xe4\x93\x02#\"!/notification/v1/project-channels\x12\xb4\x01\n\x06update\x12\x39.spaceone.api.notification.v1.UpdateProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/notification/v1/project-channel/{project_channel_id}\x12\xcb\x01\n\x0cset_schedule\x12\x41.spaceone.api.notification.v1.UpdateProjectChannelScheduleRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"F\x82\xd3\xe4\x93\x02@\x1a>/notification/v1/project-channel/{project_channel_id}/schedule\x12\xd7\x01\n\x10set_subscription\x12\x45.spaceone.api.notification.v1.UpdateProjectChannelSubscriptionRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"J\x82\xd3\xe4\x93\x02\x44\x1a\x42/notification/v1/project-channel/{project_channel_id}/subscription\x12\xb5\x01\n\x06\x65nable\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"D\x82\xd3\xe4\x93\x02>\x1a</notification/v1/project-channel/{project_channel_id}/enable\x12\xb7\x01\n\x07\x64isable\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"E\x82\xd3\xe4\x93\x02?\x1a=/notification/v1/project-channel/{project_channel_id}/disable\x12\x94\x01\n\x06\x64\x65lete\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x16.google.protobuf.Empty\"=\x82\xd3\xe4\x93\x02\x37*5/notification/v1/project-channel/{project_channel_id}\x12\xae\x01\n\x03get\x12\x36.spaceone.api.notification.v1.GetProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/notification/v1/project-channel/{project_channel_id}\x12\xc3\x01\n\x04list\x12\x31.spaceone.api.notification.v1.ProjectChannelQuery\x1a\x31.spaceone.api.notification.v1.ProjectChannelsInfo\"U\x82\xd3\xe4\x93\x02O\x12!/notification/v1/project-channelsZ*\"(/notification/v1/project-channels/search\x12\x86\x01\n\x04stat\x12\x35.spaceone.api.notification.v1.ProjectChannelStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/notification/v1/project-channels/statb\x06proto3')

_NOTIFICATIONLEVEL = DESCRIPTOR.enum_types_by_name['NotificationLevel']
NotificationLevel = enum_type_wrapper.EnumTypeWrapper(_NOTIFICATIONLEVEL)
NONE = 0
LV1 = 1
LV2 = 2
LV3 = 3
LV4 = 4
LV5 = 5


_PROJECTCHANNELSCHEDULE = DESCRIPTOR.message_types_by_name['ProjectChannelSchedule']
_CREATEPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectChannelRequest']
_UPDATEPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelRequest']
_UPDATEPROJECTCHANNELSCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelScheduleRequest']
_UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelSubscriptionRequest']
_PROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['ProjectChannelRequest']
_GETPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['GetProjectChannelRequest']
_PROJECTCHANNELQUERY = DESCRIPTOR.message_types_by_name['ProjectChannelQuery']
_PROJECTCHANNELINFO = DESCRIPTOR.message_types_by_name['ProjectChannelInfo']
_PROJECTCHANNELSINFO = DESCRIPTOR.message_types_by_name['ProjectChannelsInfo']
_PROJECTCHANNELSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectChannelStatQuery']
_PROJECTCHANNELSCHEDULE_DAYOFWEEK = _PROJECTCHANNELSCHEDULE.enum_types_by_name['DayOfWeek']
_PROJECTCHANNELQUERY_PROJECTCHANNELSTATE = _PROJECTCHANNELQUERY.enum_types_by_name['ProjectChannelState']
_PROJECTCHANNELINFO_PROJECTCHANNELSTATE = _PROJECTCHANNELINFO.enum_types_by_name['ProjectChannelState']
ProjectChannelSchedule = _reflection.GeneratedProtocolMessageType('ProjectChannelSchedule', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSCHEDULE,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelSchedule)
  })
_sym_db.RegisterMessage(ProjectChannelSchedule)

CreateProjectChannelRequest = _reflection.GeneratedProtocolMessageType('CreateProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateProjectChannelRequest)
  })
_sym_db.RegisterMessage(CreateProjectChannelRequest)

UpdateProjectChannelRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelRequest)

UpdateProjectChannelScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELSCHEDULEREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelScheduleRequest)

UpdateProjectChannelSubscriptionRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelSubscriptionRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelSubscriptionRequest)

ProjectChannelRequest = _reflection.GeneratedProtocolMessageType('ProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelRequest)
  })
_sym_db.RegisterMessage(ProjectChannelRequest)

GetProjectChannelRequest = _reflection.GeneratedProtocolMessageType('GetProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetProjectChannelRequest)
  })
_sym_db.RegisterMessage(GetProjectChannelRequest)

ProjectChannelQuery = _reflection.GeneratedProtocolMessageType('ProjectChannelQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELQUERY,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelQuery)
  })
_sym_db.RegisterMessage(ProjectChannelQuery)

ProjectChannelInfo = _reflection.GeneratedProtocolMessageType('ProjectChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELINFO,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelInfo)
  })
_sym_db.RegisterMessage(ProjectChannelInfo)

ProjectChannelsInfo = _reflection.GeneratedProtocolMessageType('ProjectChannelsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSINFO,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelsInfo)
  })
_sym_db.RegisterMessage(ProjectChannelsInfo)

ProjectChannelStatQuery = _reflection.GeneratedProtocolMessageType('ProjectChannelStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelStatQuery)
  })
_sym_db.RegisterMessage(ProjectChannelStatQuery)

_PROJECTCHANNEL = DESCRIPTOR.services_by_name['ProjectChannel']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTCHANNEL.methods_by_name['create']._options = None
  _PROJECTCHANNEL.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/notification/v1/project-channels'
  _PROJECTCHANNEL.methods_by_name['update']._options = None
  _PROJECTCHANNEL.methods_by_name['update']._serialized_options = b'\202\323\344\223\0027\0325/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['set_schedule']._options = None
  _PROJECTCHANNEL.methods_by_name['set_schedule']._serialized_options = b'\202\323\344\223\002@\032>/notification/v1/project-channel/{project_channel_id}/schedule'
  _PROJECTCHANNEL.methods_by_name['set_subscription']._options = None
  _PROJECTCHANNEL.methods_by_name['set_subscription']._serialized_options = b'\202\323\344\223\002D\032B/notification/v1/project-channel/{project_channel_id}/subscription'
  _PROJECTCHANNEL.methods_by_name['enable']._options = None
  _PROJECTCHANNEL.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002>\032</notification/v1/project-channel/{project_channel_id}/enable'
  _PROJECTCHANNEL.methods_by_name['disable']._options = None
  _PROJECTCHANNEL.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002?\032=/notification/v1/project-channel/{project_channel_id}/disable'
  _PROJECTCHANNEL.methods_by_name['delete']._options = None
  _PROJECTCHANNEL.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0027*5/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['get']._options = None
  _PROJECTCHANNEL.methods_by_name['get']._serialized_options = b'\202\323\344\223\0027\0225/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['list']._options = None
  _PROJECTCHANNEL.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/notification/v1/project-channelsZ*\"(/notification/v1/project-channels/search'
  _PROJECTCHANNEL.methods_by_name['stat']._options = None
  _PROJECTCHANNEL.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/notification/v1/project-channels/stat'
  _NOTIFICATIONLEVEL._serialized_start=2795
  _NOTIFICATIONLEVEL._serialized_end=2869
  _PROJECTCHANNELSCHEDULE._serialized_start=208
  _PROJECTCHANNELSCHEDULE._serialized_end=441
  _PROJECTCHANNELSCHEDULE_DAYOFWEEK._serialized_start=357
  _PROJECTCHANNELSCHEDULE_DAYOFWEEK._serialized_end=441
  _CREATEPROJECTCHANNELREQUEST._serialized_start=444
  _CREATEPROJECTCHANNELREQUEST._serialized_end=841
  _UPDATEPROJECTCHANNELREQUEST._serialized_start=844
  _UPDATEPROJECTCHANNELREQUEST._serialized_end=1089
  _UPDATEPROJECTCHANNELSCHEDULEREQUEST._serialized_start=1092
  _UPDATEPROJECTCHANNELSCHEDULEREQUEST._serialized_end=1270
  _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST._serialized_start=1273
  _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST._serialized_end=1406
  _PROJECTCHANNELREQUEST._serialized_start=1408
  _PROJECTCHANNELREQUEST._serialized_end=1478
  _GETPROJECTCHANNELREQUEST._serialized_start=1480
  _GETPROJECTCHANNELREQUEST._serialized_end=1567
  _PROJECTCHANNELQUERY._serialized_start=1570
  _PROJECTCHANNELQUERY._serialized_end=1979
  _PROJECTCHANNELQUERY_PROJECTCHANNELSTATE._serialized_start=1921
  _PROJECTCHANNELQUERY_PROJECTCHANNELSTATE._serialized_end=1979
  _PROJECTCHANNELINFO._serialized_start=1982
  _PROJECTCHANNELINFO._serialized_end=2582
  _PROJECTCHANNELINFO_PROJECTCHANNELSTATE._serialized_start=1921
  _PROJECTCHANNELINFO_PROJECTCHANNELSTATE._serialized_end=1979
  _PROJECTCHANNELSINFO._serialized_start=2584
  _PROJECTCHANNELSINFO._serialized_end=2693
  _PROJECTCHANNELSTATQUERY._serialized_start=2695
  _PROJECTCHANNELSTATQUERY._serialized_end=2793
  _PROJECTCHANNEL._serialized_start=2872
  _PROJECTCHANNEL._serialized_end=4691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/provisioning/v1/catalog_group.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a#spaceone/api/identity/v1/role.proto\"\xb8\x02\n\x10\x43\x61talogGroupInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Q\n\x19parent_catalog_group_info\x18\x04 \x01(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\x12\x1f\n\x17parent_catalog_group_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_by\x18\x17 \x01(\t\x12\x12\n\nupdated_at\x18\x18 \x01(\t\"]\n\x19\x43reateCatalogGroupRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xc4\x01\n\x19UpdateCatalogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x03 \x01(\t\x12$\n\x1crelease_parent_catalog_group\x18\x04 \x01(\x08\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"B\n\x13\x43\x61talogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetCatalogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xd0\x01\n\x11\x43\x61talogGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63\x61talog_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14parent_catalog_group\x18\x04 \x01(\t\x12\x15\n\rauthor_within\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x07 \x01(\t\"i\n\x11\x43\x61talogGroupsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x97\x07\n\x0c\x43\x61talogGroup\x12\xa7\x01\n\x14\x63reate_catalog_group\x12\x37.spaceone.api.provisioning.v1.CreateCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/catalog-group\x12\xba\x01\n\x14update_catalog_group\x12\x37.spaceone.api.provisioning.v1.UpdateCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/provisioning/v1/catalog-group/{catalog_group_id}\x12\x9c\x01\n\x14\x64\x65lete_catalog_group\x12\x31.spaceone.api.provisioning.v1.CatalogGroupRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33*1/provisioning/v1/catalog-group/{catalog_group_id}\x12\xb4\x01\n\x11get_catalog_group\x12\x34.spaceone.api.provisioning.v1.GetCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/provisioning/v1/catalog-group/{catalog_group_id}\x12\xc9\x01\n\x12get_catalog_groups\x12/.spaceone.api.provisioning.v1.CatalogGroupQuery\x1a/.spaceone.api.provisioning.v1.CatalogGroupsInfo\"Q\x82\xd3\xe4\x93\x02K\x12\x1f/provisioning/v1/catalog-groupsZ(\"&/provisioning/v1/catalog-groups/searchb\x06proto3')



_CATALOGGROUPINFO = DESCRIPTOR.message_types_by_name['CatalogGroupInfo']
_CREATECATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogGroupRequest']
_UPDATECATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogGroupRequest']
_CATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['CatalogGroupRequest']
_GETCATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogGroupRequest']
_CATALOGGROUPQUERY = DESCRIPTOR.message_types_by_name['CatalogGroupQuery']
_CATALOGGROUPSINFO = DESCRIPTOR.message_types_by_name['CatalogGroupsInfo']
CatalogGroupInfo = _reflection.GeneratedProtocolMessageType('CatalogGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupInfo)
  })
_sym_db.RegisterMessage(CatalogGroupInfo)

CreateCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogGroupRequest)
  })
_sym_db.RegisterMessage(CreateCatalogGroupRequest)

UpdateCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogGroupRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogGroupRequest)

CatalogGroupRequest = _reflection.GeneratedProtocolMessageType('CatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupRequest)
  })
_sym_db.RegisterMessage(CatalogGroupRequest)

GetCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('GetCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogGroupRequest)
  })
_sym_db.RegisterMessage(GetCatalogGroupRequest)

CatalogGroupQuery = _reflection.GeneratedProtocolMessageType('CatalogGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupQuery)
  })
_sym_db.RegisterMessage(CatalogGroupQuery)

CatalogGroupsInfo = _reflection.GeneratedProtocolMessageType('CatalogGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupsInfo)
  })
_sym_db.RegisterMessage(CatalogGroupsInfo)

_CATALOGGROUP = DESCRIPTOR.services_by_name['CatalogGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGGROUP.methods_by_name['create_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['create_catalog_group']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/catalog-group'
  _CATALOGGROUP.methods_by_name['update_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['update_catalog_group']._serialized_options = b'\202\323\344\223\0023\0321/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['delete_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['delete_catalog_group']._serialized_options = b'\202\323\344\223\0023*1/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['get_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['get_catalog_group']._serialized_options = b'\202\323\344\223\0023\0221/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['get_catalog_groups']._options = None
  _CATALOGGROUP.methods_by_name['get_catalog_groups']._serialized_options = b'\202\323\344\223\002K\022\037/provisioning/v1/catalog-groupsZ(\"&/provisioning/v1/catalog-groups/search'
  _CATALOGGROUPINFO._serialized_start=243
  _CATALOGGROUPINFO._serialized_end=555
  _CREATECATALOGGROUPREQUEST._serialized_start=557
  _CREATECATALOGGROUPREQUEST._serialized_end=650
  _UPDATECATALOGGROUPREQUEST._serialized_start=653
  _UPDATECATALOGGROUPREQUEST._serialized_end=849
  _CATALOGGROUPREQUEST._serialized_start=851
  _CATALOGGROUPREQUEST._serialized_end=917
  _GETCATALOGGROUPREQUEST._serialized_start=919
  _GETCATALOGGROUPREQUEST._serialized_end=1002
  _CATALOGGROUPQUERY._serialized_start=1005
  _CATALOGGROUPQUERY._serialized_end=1213
  _CATALOGGROUPSINFO._serialized_start=1215
  _CATALOGGROUPSINFO._serialized_end=1320
  _CATALOGGROUP._serialized_start=1323
  _CATALOGGROUP._serialized_end=2242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$spaceone/api/identity/v1/token.proto\x12\x18spaceone.api.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa0\x01\n\x11IssueTokenRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tuser_type\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rrefresh_count\x18\x06 \x01(\x05\"8\n\tTokenInfo\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t2\xf0\x01\n\x05Token\x12{\n\x05issue\x12+.spaceone.api.identity.v1.IssueTokenRequest\x1a#.spaceone.api.identity.v1.TokenInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/identity/v1/token/issue\x12j\n\x07refresh\x12\x16.google.protobuf.Empty\x1a#.spaceone.api.identity.v1.TokenInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/token/refreshb\x06proto3')



_ISSUETOKENREQUEST = DESCRIPTOR.message_types_by_name['IssueTokenRequest']
_TOKENINFO = DESCRIPTOR.message_types_by_name['TokenInfo']
IssueTokenRequest = _reflection.GeneratedProtocolMessageType('IssueTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISSUETOKENREQUEST,
  '__module__' : 'spaceone.api.identity.v1.token_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.IssueTokenRequest)
  })
_sym_db.RegisterMessage(IssueTokenRequest)

TokenInfo = _reflection.GeneratedProtocolMessageType('TokenInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOKENINFO,
  '__module__' : 'spaceone.api.identity.v1.token_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.TokenInfo)
  })
_sym_db.RegisterMessage(TokenInfo)

_TOKEN = DESCRIPTOR.services_by_name['Token']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOKEN.methods_by_name['issue']._options = None
  _TOKEN.methods_by_name['issue']._serialized_options = b'\202\323\344\223\002\032\"\030/identity/v1/token/issue'
  _TOKEN.methods_by_name['refresh']._options = None
  _TOKEN.methods_by_name['refresh']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/token/refresh'
  _ISSUETOKENREQUEST._serialized_start=156
  _ISSUETOKENREQUEST._serialized_end=316
  _TOKENINFO._serialized_start=318
  _TOKENINFO._serialized_end=374
  _TOKEN._serialized_start=377
  _TOKEN._serialized_end=617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/job_task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/cost_analysis/v1/job_task.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"I\n\x11GetJobTaskRequest\x12\x13\n\x0bjob_task_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xbb\x02\n\x0cJobTaskQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bjob_task_id\x18\x02 \x01(\t\x12\x42\n\x06status\x18\x03 \x01(\x0e\x32\x32.spaceone.api.cost_analysis.v1.JobTaskQuery.Status\x12\x0e\n\x06job_id\x18\x0b \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"k\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07\x46\x41ILURE\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\"\xca\x03\n\x0bJobTaskInfo\x12\x13\n\x0bjob_task_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.spaceone.api.cost_analysis.v1.JobTaskInfo.Status\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rcreated_count\x18\x04 \x01(\x05\x12\x12\n\nerror_code\x18\x05 \x01(\t\x12\x15\n\rerror_message\x18\x06 \x01(\t\x12\x0e\n\x06job_id\x18\x0b \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nstarted_at\x18\x16 \x01(\t\x12\x12\n\nupdated_at\x18\x17 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x18 \x01(\t\"k\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07\x46\x41ILURE\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\"`\n\x0cJobTasksInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.cost_analysis.v1.JobTaskInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10JobTaskStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcb\x03\n\x07JobTask\x12\x95\x01\n\x03get\x12\x30.spaceone.api.cost_analysis.v1.GetJobTaskRequest\x1a*.spaceone.api.cost_analysis.v1.JobTaskInfo\"0\x82\xd3\xe4\x93\x02*\x12(/cost-analysis/v1/job-task/{job_task_id}\x12\xab\x01\n\x04list\x12+.spaceone.api.cost_analysis.v1.JobTaskQuery\x1a+.spaceone.api.cost_analysis.v1.JobTasksInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/cost-analysis/v1/job-tasksZ$\"\"/cost-analysis/v1/job-tasks/search\x12z\n\x04stat\x12/.spaceone.api.cost_analysis.v1.JobTaskStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /cost-analysis/v1/job-tasks/statb\x06proto3')



_GETJOBTASKREQUEST = DESCRIPTOR.message_types_by_name['GetJobTaskRequest']
_JOBTASKQUERY = DESCRIPTOR.message_types_by_name['JobTaskQuery']
_JOBTASKINFO = DESCRIPTOR.message_types_by_name['JobTaskInfo']
_JOBTASKSINFO = DESCRIPTOR.message_types_by_name['JobTasksInfo']
_JOBTASKSTATQUERY = DESCRIPTOR.message_types_by_name['JobTaskStatQuery']
_JOBTASKQUERY_STATUS = _JOBTASKQUERY.enum_types_by_name['Status']
_JOBTASKINFO_STATUS = _JOBTASKINFO.enum_types_by_name['Status']
GetJobTaskRequest = _reflection.GeneratedProtocolMessageType('GetJobTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBTASKREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetJobTaskRequest)
  })
_sym_db.RegisterMessage(GetJobTaskRequest)

JobTaskQuery = _reflection.GeneratedProtocolMessageType('JobTaskQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobTaskQuery)
  })
_sym_db.RegisterMessage(JobTaskQuery)

JobTaskInfo = _reflection.GeneratedProtocolMessageType('JobTaskInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobTaskInfo)
  })
_sym_db.RegisterMessage(JobTaskInfo)

JobTasksInfo = _reflection.GeneratedProtocolMessageType('JobTasksInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobTasksInfo)
  })
_sym_db.RegisterMessage(JobTasksInfo)

JobTaskStatQuery = _reflection.GeneratedProtocolMessageType('JobTaskStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobTaskStatQuery)
  })
_sym_db.RegisterMessage(JobTaskStatQuery)

_JOBTASK = DESCRIPTOR.services_by_name['JobTask']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOBTASK.methods_by_name['get']._options = None
  _JOBTASK.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\022(/cost-analysis/v1/job-task/{job_task_id}'
  _JOBTASK.methods_by_name['list']._options = None
  _JOBTASK.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/cost-analysis/v1/job-tasksZ$\"\"/cost-analysis/v1/job-tasks/search'
  _JOBTASK.methods_by_name['stat']._options = None
  _JOBTASK.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /cost-analysis/v1/job-tasks/stat'
  _GETJOBTASKREQUEST._serialized_start=173
  _GETJOBTASKREQUEST._serialized_end=246
  _JOBTASKQUERY._serialized_start=249
  _JOBTASKQUERY._serialized_end=564
  _JOBTASKQUERY_STATUS._serialized_start=457
  _JOBTASKQUERY_STATUS._serialized_end=564
  _JOBTASKINFO._serialized_start=567
  _JOBTASKINFO._serialized_end=1025
  _JOBTASKINFO_STATUS._serialized_start=457
  _JOBTASKINFO_STATUS._serialized_end=564
  _JOBTASKSINFO._serialized_start=1027
  _JOBTASKSINFO._serialized_end=1123
  _JOBTASKSTATQUERY._serialized_start=1125
  _JOBTASKSTATQUERY._serialized_end=1216
  _JOBTASK._serialized_start=1219
  _JOBTASK._serialized_end=1678
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.identity.v1 import user_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2


class UserStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.identity.v1.User/create',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.identity.v1.User/update',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.set_required_actions = channel.unary_unary(
                '/spaceone.api.identity.v1.User/set_required_actions',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.SetRequiredActionsRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.identity.v1.User/enable',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.identity.v1.User/disable',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.identity.v1.User/delete',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.identity.v1.User/get',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.GetUserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.identity.v1.User/list',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UsersInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.identity.v1.User/stat',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.find = channel.unary_unary(
                '/spaceone.api.identity.v1.User/find',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUserQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUsersInfo.FromString,
                )
        self.sync = channel.unary_unary(
                '/spaceone.api.identity.v1.User/sync',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
                )


class UserServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Update user info by given user_id
        note:
        request_example: >-
        {
        "user_id": "dkang@mz.co.kr",
        "tags": [{
        "key": "user1",
        "value": "Reuters"
        }, {
        "key": "user2",
        "value": "Bloomberg"
        }],
        "domain_id": "{{DOMAIN_ID}}"
        }
        response_example: >-
        {
        "user_id": "dkang@mz.co.kr",
        "name": "Dong Yoo kang",
        "state": "ENABLED",
        "email": "dkang@mz.co.kr",
        "language": "en",
        "timezone": "UTC",
        "tags": [{
        "key": "user1",
        "value": "Reuters"
        }, {
        "key": "user2",
        "value": "Bloomberg"
        }],
        "last_accessed_at": {
        "seconds": "1593161630",
        "nanos": 79000000
        },
        "created_at": {
        "seconds": "1593161630",
        "nanos": 79000000
        },
        "domain_id": "domain-fd6e23a5ae36"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_required_actions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def find(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def sync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.CreateUserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UpdateUserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'set_required_actions': grpc.unary_unary_rpc_method_handler(
                    servicer.set_required_actions,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.SetRequiredActionsRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.GetUserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UsersInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'find': grpc.unary_unary_rpc_method_handler(
                    servicer.find,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUserQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUsersInfo.SerializeToString,
            ),
            'sync': grpc.unary_unary_rpc_method_handler(
                    servicer.sync,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.identity.v1.User', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class User(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/create',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.CreateUserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/update',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UpdateUserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_required_actions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/set_required_actions',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.SetRequiredActionsRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/enable',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/disable',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/delete',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/get',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.GetUserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/list',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UsersInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/stat',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/find',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUserQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.FindUsersInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def sync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.User/sync',
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_user__pb2.UserInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import data_source_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2


class DataSourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/register',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/enable',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/disable',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/deregister',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/update_plugin',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/verify_plugin',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourcesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.DataSource/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class DataSourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """
        desc: Registers a DataSource with information of the plugin to use. Information of the plugin includes `version`, `provider`, `upgrade_mode`.
        request_example: >-
        {
        "name": "datasource-test",
        "plugin_info": {"plugin_id": "plugin-123456789012",
        "version": "1.1.4.20220617.135934",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_resource_type": ["inventory.Server", "inventory.CloudService"],
        "required_keys": ["data.cloudwatch"],
        "supported_stat": ["AVERAGE", "MAX", "MIN", "SUM"]},
        "upgrade_mode": "AUTO"
        },
        "tags": {"a": "b"},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-123456789012",
        "name": "datasource-test",
        "state": "ENABLED",
        "monitoring_type": "METRIC",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ],
        "use_resource_secret": true,
        "monitoring_type": "METRIC"
        },
        "plugin_info": {
        "plugin_id": "plugin-123456789012",
        "version": "1.1.4.20220617.135934",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_stat": [
        "AVERAGE",
        "MAX",
        "MIN",
        "SUM"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ],
        "required_keys": [
        "data.cloudwatch"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-06-21T01:17:12.144Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific DataSource. You can make changes in DataSource settings, including `name` and `tags`.
        request_example: >-
        {
        "data_source_id": "ds-123456789012",
        "name": "tmp-datasource_test",
        "tags": {"b": "c"},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-123456789012",
        "name": "tmp-datasource_test",
        "state": "ENABLED",
        "monitoring_type": "METRIC",
        "provider": "aws",
        "capability": {
        "use_resource_secret": true,
        "monitoring_type": "METRIC",
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-123456789012",
        "version": "1.1.4.20220617.135934",
        "options": {},
        "provider": "aws",
        "metadata": {
        "required_keys": [
        "data.cloudwatch"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ],
        "supported_stat": [
        "AVERAGE",
        "MAX",
        "MIN",
        "SUM"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "b": "c"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-06-21T01:17:12.144Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific DataSource. By enabling a DataSource, you can communicate with an external cloud service via the plugin.
        request_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "name": "tmp-datasource_test",
        "state": "ENABLED",
        "monitoring_type": "METRIC",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ],
        "monitoring_type": "METRIC",
        "use_resource_secret": true
        },
        "plugin_info": {
        "plugin_id": "plugin-5cdf8d72a7cc",
        "version": "1.1.4.20220617.135934",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_stat": [
        "AVERAGE",
        "MAX",
        "MIN",
        "SUM"
        ],
        "required_keys": [
        "data.cloudwatch"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "b": "c"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-06-21T01:17:12.144Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific DataSource. By disabling a DataSource, you can block communication with an external cloud service via the plugin.
        request_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "name": "tmp-datasource_test",
        "state": "DISABLED",
        "monitoring_type": "METRIC",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ],
        "monitoring_type": "METRIC",
        "use_resource_secret": true
        },
        "plugin_info": {
        "plugin_id": "plugin-5cdf8d72a7cc",
        "version": "1.1.4.20220617.135934",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_stat": [
        "AVERAGE",
        "MAX",
        "MIN",
        "SUM"
        ],
        "required_keys": [
        "data.cloudwatch"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "b": "c"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-06-21T01:17:12.144Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """
        desc: Deregisters and deletes a specific DataSource. You must specify the `data_source_id` of the DataSource to deregister.
        request_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """
        desc: Updates the plugin of a specific DataSource. This method resets the plugin data in the DataSource to update the `metadata`.
        request_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "version": "1.1.3",
        "options": {},
        "upgrade_mode": "MANUAL",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "name": "tmp-datasource_test",
        "state": "ENABLED",
        "monitoring_type": "METRIC",
        "provider": "aws",
        "capability": {
        "use_resource_secret": true,
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ],
        "monitoring_type": "METRIC"
        },
        "plugin_info": {
        "plugin_id": "plugin-5cdf8d72a7cc",
        "version": "1.1.3",
        "options": {},
        "provider": "aws",
        "metadata": {
        "required_keys": [
        "data.cloudwatch"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ],
        "supported_stat": [
        "AVERAGE",
        "MAX",
        "MIN",
        "SUM"
        ]
        },
        "upgrade_mode": "MANUAL"
        },
        "tags": {
        "b": "c"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-06-21T01:17:12.144Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """
        desc: Verifies the plugin of a specific DataSource. This method validates the plugin data, `version` and `endpoint`.
        request_example: >-
        {
        "data_source_id": "ds-6167ed6b42f4",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific DataSource. Prints detailed information about the DataSource, including `name`, `state`, and `plugin_info`.
        request_example: >-
        {
        "data_source_id": "ds-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data_source_id": "ds-89f1e81528e9",
        "name": "AWS CloudTrail",
        "state": "ENABLED",
        "monitoring_type": "LOG",
        "provider": "aws",
        "capability": {
        "use_resource_secret": true,
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ],
        "monitoring_type": "LOG"
        },
        "plugin_info": {
        "plugin_id": "plugin-9881b9b440a4",
        "version": "1.0-dev2",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ],
        "required_keys": [
        "reference.resource_id"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2021-03-31T08:39:45.532Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all DataSources. You can use a query to get a filtered list of DataSources.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "data_source_id": "ds-89f1e81528e9",
        "name": "AWS CloudTrail",
        "state": "ENABLED",
        "monitoring_type": "LOG",
        "provider": "aws",
        "capability": {
        "use_resource_secret": true,
        "monitoring_type": "LOG",
        "supported_schema": [
        "aws_access_key",
        "aws_assume_role"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-9881b9b440a4",
        "version": "1.0-dev2",
        "options": {},
        "provider": "aws",
        "metadata": {
        "required_keys": [
        "reference.resource_id"
        ],
        "supported_resource_type": [
        "inventory.Server",
        "inventory.CloudService"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2021-03-31T08:39:45.532Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.GetDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourcesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.DataSource', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSource(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/register',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/enable',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/disable',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/deregister',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/update_plugin',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/verify_plugin',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourcesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.DataSource/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_data__source__pb2.DataSourceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/plugin/webhook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/monitoring/plugin/webhook.proto\x12\x1espaceone.api.monitoring.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\">\n\x12WebhookInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"F\n\x1aWebhookPluginVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x11WebhookPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xda\x01\n\x07Webhook\x12o\n\x04init\x12\x32.spaceone.api.monitoring.plugin.WebhookInitRequest\x1a\x31.spaceone.api.monitoring.plugin.WebhookPluginInfo\"\x00\x12^\n\x06verify\x12:.spaceone.api.monitoring.plugin.WebhookPluginVerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_WEBHOOKINITREQUEST = DESCRIPTOR.message_types_by_name['WebhookInitRequest']
_WEBHOOKPLUGINVERIFYREQUEST = DESCRIPTOR.message_types_by_name['WebhookPluginVerifyRequest']
_WEBHOOKPLUGININFO = DESCRIPTOR.message_types_by_name['WebhookPluginInfo']
WebhookInitRequest = _reflection.GeneratedProtocolMessageType('WebhookInitRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKINITREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookInitRequest)
  })
_sym_db.RegisterMessage(WebhookInitRequest)

WebhookPluginVerifyRequest = _reflection.GeneratedProtocolMessageType('WebhookPluginVerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKPLUGINVERIFYREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookPluginVerifyRequest)
  })
_sym_db.RegisterMessage(WebhookPluginVerifyRequest)

WebhookPluginInfo = _reflection.GeneratedProtocolMessageType('WebhookPluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKPLUGININFO,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookPluginInfo)
  })
_sym_db.RegisterMessage(WebhookPluginInfo)

_WEBHOOK = DESCRIPTOR.services_by_name['Webhook']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WEBHOOKINITREQUEST._serialized_start=139
  _WEBHOOKINITREQUEST._serialized_end=201
  _WEBHOOKPLUGINVERIFYREQUEST._serialized_start=203
  _WEBHOOKPLUGINVERIFYREQUEST._serialized_end=273
  _WEBHOOKPLUGININFO._serialized_start=275
  _WEBHOOKPLUGININFO._serialized_end=337
  _WEBHOOK._serialized_start=340
  _WEBHOOK._serialized_end=558
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.notification.plugin import notification_pb2 as spaceone_dot_api_dot_notification_dot_plugin_dot_notification__pb2


class NotificationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.dispatch = channel.unary_unary(
                '/spaceone.api.notification.plugin.Notification/dispatch',
                request_serializer=spaceone_dot_api_dot_notification_dot_plugin_dot_notification__pb2.PluginDispatchRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class NotificationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def dispatch(self, request, context):
        """
        desc: Dispatches data from Cloudforet to a specific notification Protocol. When dispatching data, data input by a User is included in the `options` parameter, and `notification` information to be delivered is included in the `message` parameter. Also, data dispatched includes basic information such as `notification_type` and `secret_data`.
        request_example: >-
        {
        "options": {},
        "message": {
        "tags": [
        {
        "key": "Alert Number",
        "options": {"short": true},
        "value": "#108664"
        },
        {
        "options": {"short": true},
        "key": "State",
        "value": "TRIGGERED"
        },
        {
        "value": "LOW",
        "options": {"short": true},
        "key": "Urgency"
        },
        {
        "value": "kubectl-webhook",
        "key": "Triggered by",
        "options": {"short": true}
        },
        {
        "value": "SpaceONE > Project1",
        "key": "Project"
        },
        {
        "value": "spaceone-api",
        "key": "Resource"
        }
        ],
        "occurred_at": "2022-06-27T09:22:57.967Z",
        "callbacks": [{
        "url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/alert/alert-x1v2c3v456/8f2ede36213dqw4d7d5awe07ds32d883/ACKNOWLEDGED",
        "label": "Acknowledge Alerts"}],
        "link": "https://spaceone.console.dev.spaceone.dev/alert-manager/alert/alert-x1v2c3v456",
        "title": "[Alerting] Notification of access to the SpaceONE",
        "description": "SSH Access to spaceone-api from admin"},
        "notification_type": "INFO",
        "secret_data": "********",
        "channel_data": {"email": "test5@test.com"}
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'dispatch': grpc.unary_unary_rpc_method_handler(
                    servicer.dispatch,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_plugin_dot_notification__pb2.PluginDispatchRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.plugin.Notification', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Notification(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def dispatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.plugin.Notification/dispatch',
            spaceone_dot_api_dot_notification_dot_plugin_dot_notification__pb2.PluginDispatchRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
